API Reference
=============

This section contains the complete API documentation for HBAT.

Core Package
------------

.. toctree::
   :maxdepth: 2
   
   core/index

CCD Package
-----------

.. toctree::
   :maxdepth: 2
   
   ccd/index

Command Line Interface
----------------------

.. toctree::
   :maxdepth: 2
   
   cli/index

Graphical User Interface
------------------------

.. toctree::
   :maxdepth: 2
   
   gui/index

Constants
---------

.. toctree::
   :maxdepth: 2
   
   constants/index

Utilities
---------

.. toctree::
   :maxdepth: 2
   
   utilities/index

API Usage Examples
------------------

.. toctree::
   :maxdepth: 2
   
   examples/index